"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var base_1 = require("../unit/base");
var measure_1 = require("./measure");
exports.pow = measure_1.pow;
var unitValueArithmetic_1 = require("./unitValueArithmetic");
exports.abs = wrapUnary(Math.abs);
exports.acos = wrapInverseTrig(Math.acos);
exports.asin = wrapInverseTrig(Math.asin);
exports.atan = wrapInverseTrig(Math.atan);
exports.ceil = wrapUnary(Math.ceil);
exports.cos = wrapTrig(Math.cos);
exports.floor = wrapUnary(Math.floor);
exports.fround = wrapUnary(Math.fround);
exports.hypot = warpNary(Math.hypot);
exports.max = warpNary(Math.max);
exports.min = warpNary(Math.min);
exports.round = wrapUnary(Math.round);
exports.sin = wrapTrig(Math.sin);
exports.tan = wrapTrig(Math.tan);
exports.trunc = wrapUnary(Math.trunc);
function atan2(y, x) {
    return measure_1.Measure.of(Math.atan2(y.value, x.value), base_1.radians);
}
exports.atan2 = atan2;
function sqrt(x) {
    return measure_1.Measure.unsafeConstruct(Math.sqrt(x.value), unitValueArithmetic_1.nthRootUnit(x.getUnit(), 2));
}
exports.sqrt = sqrt;
function cbrt(x) {
    return measure_1.Measure.unsafeConstruct(Math.cbrt(x.value), unitValueArithmetic_1.nthRootUnit(x.getUnit(), 3));
}
exports.cbrt = cbrt;
function add(left, right) {
    return left.plus(right);
}
exports.add = add;
function subtract(left, right) {
    return left.minus(right);
}
exports.subtract = subtract;
function multiply(left, right) {
    return left.times(right);
}
exports.multiply = multiply;
function divide(left, right) {
    return left.over(right);
}
exports.divide = divide;
function sum(first) {
    var rest = [];
    for (var _i = 1; _i < arguments.length; _i++) {
        rest[_i - 1] = arguments[_i];
    }
    var result = first;
    for (var _a = 0, rest_1 = rest; _a < rest_1.length; _a++) {
        var measure = rest_1[_a];
        result = result.plus(measure);
    }
    return result;
}
exports.sum = sum;
function wrapUnary(f) {
    return function (x) { return measure_1.Measure.of(f(x.value), x.normalized()); };
}
function wrapTrig(f) {
    return function (angle) { return measure_1.Measure.dimensionless(f(angle.value)); };
}
function wrapInverseTrig(f) {
    return function (angle) { return measure_1.Measure.of(f(angle.value), base_1.radians); };
}
function warpNary(f) {
    return function (first) {
        var rest = [];
        for (var _i = 1; _i < arguments.length; _i++) {
            rest[_i - 1] = arguments[_i];
        }
        return measure_1.Measure.of(f.apply(void 0, values.apply(void 0, [first].concat(rest))), first.normalized());
    };
}
function values() {
    var measures = [];
    for (var _i = 0; _i < arguments.length; _i++) {
        measures[_i] = arguments[_i];
    }
    return measures.map(function (measure) { return measure.value; });
}
//# sourceMappingURL=math.js.map