import { Exponent } from "../exponent";
import { BaseUnit, DivideUnits, DivisorUnit, ExponentiateUnit, MultiplicandUnit, MultiplyUnits, Unit, UnitWithSymbols } from "./unitTypeArithmetic";
export declare class Measure<U extends Unit> {
    readonly value: number;
    private readonly unit;
    private readonly symbol?;
    static dimension<Dim extends string>(dim: Dim, symbol?: string): Measure<{
        [D in Dim]: 1;
    }>;
    static dimensionless(value: number): Measure<{}>;
    static of<U extends Unit>(value: number, quantity: Measure<U>, symbol?: string): Measure<U>;
    static unsafeConstruct<U extends Unit>(value: number, unit: UnitWithSymbols<U>, symbol?: string): Measure<U>;
    private constructor();
    withSymbol(symbol: string): Measure<U>;
    getSymbol(): string | undefined;
    getUnit(): UnitWithSymbols<U>;
    normalized(): Measure<U>;
    plus(other: Measure<U>): Measure<U>;
    minus(other: Measure<U>): Measure<U>;
    negate(): Measure<U>;
    scale(value: number | Measure<{}>): Measure<U>;
    times<V extends MultiplicandUnit<U>>(other: Measure<V>): Measure<MultiplyUnits<U, V>>;
    over<V extends DivisorUnit<U>>(other: Measure<V>): Measure<DivideUnits<U, V>>;
    per<V extends DivisorUnit<U>>(other: Measure<V>): Measure<DivideUnits<U, V>>;
    inverse(): Measure<ExponentiateUnit<U, -1>>;
    reciprocal(): Measure<ExponentiateUnit<U, -1>>;
    compareTo(other: Measure<U>): number;
    isLessThan(other: Measure<U>): boolean;
    isLessThanOrEqualTo(other: Measure<U>): boolean;
    isEqualTo(other: Measure<U>): boolean;
    isNotEqualTo(other: Measure<U>): boolean;
    isGreaterThanOrEqualTo(other: Measure<U>): boolean;
    isGreaterThan(other: Measure<U>): boolean;
    toString(): string;
    in(unit: Measure<U>): string;
}
export interface Measure<U extends Unit> {
    squared: U extends BaseUnit<2> ? () => Measure<ExponentiateUnit<U, 2>> : never;
    cubed: U extends BaseUnit<3> ? () => Measure<ExponentiateUnit<U, 3>> : never;
}
export declare function square<U extends BaseUnit<2>>(measure: Measure<U>): Measure<ExponentiateUnit<U, 2>>;
export declare function cubic<U extends BaseUnit<3>>(measure: Measure<U>): Measure<ExponentiateUnit<U, 3>>;
export declare function pow<U extends BaseUnit<N>, N extends Exponent>(measure: Measure<U>, power: N): Measure<ExponentiateUnit<U, N>>;
