import { Measure } from "../measure/measure";
import * as Base from "../unit/base";
export declare const Dimensionless: Measure<{}>;
export declare type Dimensionless = typeof Dimensionless;
export declare type Length = typeof Base.meters;
export declare const Length: Length;
export declare type Mass = typeof Base.kilograms;
export declare const Mass: Mass;
export declare type Time = typeof Base.seconds;
export declare const Time: Time;
export declare type ElectricCurrent = typeof Base.amperes;
export declare const ElectricCurrent: ElectricCurrent;
export declare type Temperature = typeof Base.kelvin;
export declare const Temperature: Temperature;
export declare type AmountOfSubstance = typeof Base.moles;
export declare const AmountOfSubstance: AmountOfSubstance;
export declare type LuminousIntensity = typeof Base.candela;
export declare const LuminousIntensity: LuminousIntensity;
export declare type PlaneAngle = typeof Base.radians;
export declare const PlaneAngle: PlaneAngle;
export declare type SolidAngle = typeof Base.steradians;
export declare const SolidAngle: SolidAngle;
export declare const Frequency: Measure<Pick<{
    time: -1;
}, "time">>;
export declare type Frequency = typeof Frequency;
export declare const FrequencyDrift: Measure<Pick<{
    time: -2;
}, "time">>;
export declare type FrequencyDrift = typeof FrequencyDrift;
export declare const FuelEfficiency: Measure<Pick<{
    length: -2;
}, "length">>;
export declare type FuelEfficiency = typeof FuelEfficiency;
export declare const Wavenumber: Measure<Pick<{
    length: -1;
}, "length">>;
export declare type Wavenumber = typeof Wavenumber;
export declare const Area: Measure<Pick<{
    length: 2;
}, "length">>;
export declare type Area = typeof Area;
export declare const Volume: Measure<Pick<{
    length: 3;
}, "length">>;
export declare type Volume = typeof Volume;
export declare const Absement: Measure<Pick<{
    length: 1;
    time: 1;
}, "length" | "time">>;
export declare type Absement = typeof Absement;
export declare const Velocity: Measure<Pick<{
    length: 1;
    time: -1;
}, "length" | "time">>;
export declare type Velocity = typeof Velocity;
export declare const Acceleration: Measure<Pick<{
    length: 1;
    time: -2;
}, "length" | "time">>;
export declare type Acceleration = typeof Acceleration;
export declare const Jerk: Measure<Pick<{
    length: 1;
    time: -3;
}, "length" | "time">>;
export declare type Jerk = typeof Jerk;
export declare const Jounce: Measure<Pick<{
    length: 1;
    time: -4;
}, "length" | "time">>;
export declare type Jounce = typeof Jounce;
export declare const Crackle: Measure<Pick<{
    length: 1;
    time: -5;
}, "length" | "time">>;
export declare type Crackle = typeof Crackle;
export declare const VolumetricFlow: Measure<Pick<{
    length: 3;
    time: -1;
}, "length" | "time">>;
export declare type VolumetricFlow = typeof VolumetricFlow;
export declare const MassFlowRate: Measure<Pick<{
    mass: 1;
    time: -1;
}, "mass" | "time">>;
export declare type MassFlowRate = typeof MassFlowRate;
export declare const LinearDensity: Measure<Pick<{
    length: -1;
    mass: 1;
}, "length" | "mass">>;
export declare type LinearDensity = typeof LinearDensity;
export declare const AreaDensity: Measure<Pick<{
    length: -2;
    mass: 1;
}, "length" | "mass">>;
export declare type AreaDensity = typeof AreaDensity;
export declare const VolumeDensity: Measure<Pick<{
    length: -3;
    mass: 1;
}, "length" | "mass">>;
export declare type VolumeDensity = typeof VolumeDensity;
export declare const Force: Measure<Pick<{
    length: 1;
    mass: 1;
    time: -2;
}, "length" | "mass" | "time">>;
export declare type Force = typeof Force;
export declare const Yank: Measure<Pick<{
    length: 1;
    mass: 1;
    time: -3;
}, "length" | "mass" | "time">>;
export declare type Yank = typeof Yank;
export declare const Pressure: Measure<Pick<{
    length: -1;
    mass: 1;
    time: -2;
}, "length" | "mass" | "time">>;
export declare type Pressure = typeof Pressure;
export declare const Compressibility: Measure<Pick<{
    length: 1;
    mass: -1;
    time: 2;
}, "length" | "mass" | "time">>;
export declare type Compressibility = typeof Compressibility;
export declare const DynamicViscosity: Measure<Pick<{
    length: -1;
    mass: 1;
    time: -1;
}, "length" | "mass" | "time">>;
export declare type DynamicViscosity = typeof DynamicViscosity;
export declare const SurfaceTension: Measure<Pick<{
    length: 0;
    mass: 1;
    time: -2;
}, "mass" | "time">>;
export declare type SurfaceTension = typeof SurfaceTension;
export declare const Momentum: Measure<Pick<{
    length: 1;
    mass: 1;
    time: -1;
}, "length" | "mass" | "time">>;
export declare type Momentum = typeof Momentum;
export declare const MomentOfInertia: Measure<Pick<{
    length: 2;
    mass: 1;
}, "length" | "mass">>;
export declare type MomentOfInertia = typeof MomentOfInertia;
export declare const Energy: Measure<Pick<{
    length: 2;
    mass: 1;
    time: -2;
}, "length" | "mass" | "time">>;
export declare type Energy = typeof Energy;
export declare const Power: Measure<Pick<{
    length: 2;
    mass: 1;
    time: -3;
}, "length" | "mass" | "time">>;
export declare type Power = typeof Power;
export declare const PowerDensity: Measure<Pick<{
    length: -1;
    mass: 1;
    time: -3;
}, "length" | "mass" | "time">>;
export declare type PowerDensity = typeof PowerDensity;
export declare const Voltage: Measure<Pick<{
    length: 2;
    mass: 1;
    time: -3;
    current: -1;
}, "length" | "mass" | "time" | "current">>;
export declare type Voltage = typeof Voltage;
export declare const ElectricCharge: Measure<Pick<{
    time: 1;
    current: 1;
}, "time" | "current">>;
export declare type ElectricCharge = typeof ElectricCharge;
export declare const ElectricChargeDensity: Measure<Pick<{
    length: -3;
    current: 1;
}, "length" | "current">>;
export declare type ElectricChargeDensity = typeof ElectricChargeDensity;
export declare const ElectricCurrentDensity: Measure<Pick<{
    length: -2;
    current: 1;
}, "length" | "current">>;
export declare type ElectricCurrentDensity = typeof ElectricCurrentDensity;
export declare const ElectricDisplacement: Measure<Pick<{
    length: -2;
    time: 1;
    current: 1;
}, "length" | "time" | "current">>;
export declare type ElectricDisplacement = typeof ElectricDisplacement;
export declare const EletricFieldStrength: Measure<Pick<{
    length: 1;
    mass: 1;
    time: -3;
    current: -1;
}, "length" | "mass" | "time" | "current">>;
export declare type EletricFieldStrength = typeof EletricFieldStrength;
export declare const ElectricalCapacitance: Measure<Pick<{
    length: -2;
    mass: -1;
    time: 4;
    current: 2;
}, "length" | "mass" | "time" | "current">>;
export declare type ElectricalCapacitance = typeof ElectricalCapacitance;
export declare const ElectricalConductance: Measure<Pick<{
    length: -2;
    mass: -1;
    time: 3;
    current: 2;
}, "length" | "mass" | "time" | "current">>;
export declare type ElectricalConductance = typeof ElectricalConductance;
export declare const ElectricalConductivity: Measure<Pick<{
    length: -3;
    mass: -1;
    time: 3;
    current: 2;
}, "length" | "mass" | "time" | "current">>;
export declare type ElectricalConductivity = typeof ElectricalConductivity;
export declare const ElectricalResistance: Measure<Pick<{
    length: 2;
    mass: 1;
    time: -3;
    current: -2;
}, "length" | "mass" | "time" | "current">>;
export declare type ElectricalResistance = typeof ElectricalResistance;
export declare const ElectricalResistivity: Measure<Pick<{
    length: 3;
    mass: 1;
    time: -3;
    current: -2;
}, "length" | "mass" | "time" | "current">>;
export declare type ElectricalResistivity = typeof ElectricalResistivity;
export declare const ElectricalInductance: Measure<Pick<{
    length: 2;
    mass: 1;
    time: -2;
    current: -2;
}, "length" | "mass" | "time" | "current">>;
export declare type ElectricalInductance = typeof ElectricalInductance;
export declare const LinearChargeDensity: Measure<Pick<{
    length: -1;
    time: 1;
    current: 1;
}, "length" | "time" | "current">>;
export declare type LinearChargeDensity = typeof LinearChargeDensity;
export declare const Permittivity: Measure<Pick<{
    length: -3;
    mass: -1;
    time: 4;
    current: 2;
}, "length" | "mass" | "time" | "current">>;
export declare type Permittivity = typeof Permittivity;
export declare const MagneticFlux: Measure<Pick<{
    length: 2;
    mass: 1;
    time: -2;
    current: -1;
}, "length" | "mass" | "time" | "current">>;
export declare type MagneticFlux = typeof MagneticFlux;
export declare const MagneticFluxDensity: Measure<Pick<{
    length: 0;
    mass: 1;
    time: -2;
    current: -1;
}, "mass" | "time" | "current">>;
export declare type MagneticFluxDensity = typeof MagneticFluxDensity;
export declare const MagneticPermeability: Measure<Pick<{
    length: 1;
    mass: 1;
    time: -2;
    current: -2;
}, "length" | "mass" | "time" | "current">>;
export declare type MagneticPermeability = typeof MagneticPermeability;
export declare const Magnetization: Measure<Pick<{
    length: -1;
    current: 1;
}, "length" | "current">>;
export declare type Magnetization = typeof Magnetization;
export declare const MagneticReluctance: Measure<Pick<{
    length: -2;
    mass: -1;
    time: 2;
    current: 2;
}, "length" | "mass" | "time" | "current">>;
export declare type MagneticReluctance = typeof MagneticReluctance;
export declare const MagneticMoment: Measure<Pick<{
    length: 3;
    mass: 1;
    time: -2;
    current: -1;
}, "length" | "mass" | "time" | "current">>;
export declare type MagneticMoment = typeof MagneticMoment;
export declare const MagneticRigidity: Measure<Pick<{
    length: 1;
    mass: 1;
    time: -2;
    current: -1;
}, "length" | "mass" | "time" | "current">>;
export declare type MagneticRigidity = typeof MagneticRigidity;
export declare const MagneticDipoleMoment: Measure<Pick<{
    length: 2;
    mass: 0;
    time: 0;
    current: 1;
}, "length" | "current">>;
export declare type MagneticDipoleMoment = typeof MagneticDipoleMoment;
export declare const MagneticSusceptibility: Measure<Pick<{
    length: -1;
    mass: -1;
    time: 2;
    current: 2;
}, "length" | "mass" | "time" | "current">>;
export declare type MagneticSusceptibility = typeof MagneticSusceptibility;
export declare const Irradiance: Measure<Pick<{
    length: 0;
    mass: 1;
    time: -3;
}, "mass" | "time">>;
export declare type Irradiance = typeof Irradiance;
export declare const Entropy: Measure<Pick<{
    length: 2;
    mass: 1;
    time: -2;
    temperature: -1;
}, "length" | "mass" | "time" | "temperature">>;
export declare type Entropy = typeof Entropy;
export declare const SpecificHeat: Measure<Pick<{
    length: 2;
    mass: 0;
    time: -2;
    temperature: -1;
}, "length" | "time" | "temperature">>;
export declare type SpecificHeat = typeof SpecificHeat;
export declare const SpecificVolume: Measure<Pick<{
    length: 3;
    mass: -1;
}, "length" | "mass">>;
export declare type SpecificVolume = typeof SpecificVolume;
export declare const ThermalConductivity: Measure<Pick<{
    length: 1;
    mass: 1;
    time: -3;
    temperature: -1;
}, "length" | "mass" | "time" | "temperature">>;
export declare type ThermalConductivity = typeof ThermalConductivity;
export declare const ThermalResistance: Measure<Pick<{
    length: -2;
    mass: -1;
    time: 3;
    temperature: 1;
}, "length" | "mass" | "time" | "temperature">>;
export declare type ThermalResistance = typeof ThermalResistance;
export declare const ThermalExpansionCoefficient: Measure<Pick<{
    temperature: -1;
}, "temperature">>;
export declare type ThermalExpansionCoefficient = typeof ThermalExpansionCoefficient;
export declare const ThermalGradient: Measure<Pick<{
    length: -1;
    temperature: 1;
}, "length" | "temperature">>;
export declare type ThermalGradient = typeof ThermalGradient;
export declare const MolarEntropy: Measure<Pick<{
    length: 2;
    mass: 1;
    time: -2;
    temperature: -1;
    substance: -1;
}, "length" | "mass" | "time" | "temperature" | "substance">>;
export declare type MolarEntropy = typeof MolarEntropy;
export declare const MolarEnergy: Measure<Pick<{
    length: 2;
    mass: 1;
    time: -2;
    substance: -1;
}, "length" | "mass" | "time" | "substance">>;
export declare type MolarEnergy = typeof MolarEnergy;
export declare const Molarity: Measure<Pick<{
    length: -3;
    substance: 1;
}, "length" | "substance">>;
export declare type Molarity = typeof Molarity;
export declare const MolarVolume: Measure<Pick<{
    length: 3;
    substance: -1;
}, "length" | "substance">>;
export declare type MolarVolume = typeof MolarVolume;
export declare const Molality: Measure<Pick<{
    mass: -1;
    substance: 1;
}, "mass" | "substance">>;
export declare type Molality = typeof Molality;
export declare const MolarMass: Measure<Pick<{
    mass: 1;
    substance: -1;
}, "mass" | "substance">>;
export declare type MolarMass = typeof MolarMass;
export declare const MolarConductivity: Measure<Pick<{
    mass: -1;
    time: 3;
    current: 2;
    substance: -1;
}, "mass" | "time" | "current" | "substance">>;
export declare type MolarConductivity = typeof MolarConductivity;
export declare const CatalyticActivity: Measure<Pick<{
    time: -1;
    substance: 1;
}, "time" | "substance">>;
export declare type CatalyticActivity = typeof CatalyticActivity;
export declare const CatalyticEfficiency: Measure<Pick<{
    length: 3;
    time: -1;
    substance: -1;
}, "length" | "time" | "substance">>;
export declare type CatalyticEfficiency = typeof CatalyticEfficiency;
export declare const ReactionRate: Measure<Pick<{
    length: -3;
    time: -1;
    substance: 1;
}, "length" | "time" | "substance">>;
export declare type ReactionRate = typeof ReactionRate;
export declare const RadiationDose: Measure<Pick<{
    length: 2;
    mass: 0;
    time: -2;
}, "length" | "time">>;
export declare type RadiationDose = typeof RadiationDose;
export declare const RadiationDoseRate: Measure<Pick<{
    length: 2;
    time: -3;
}, "length" | "time">>;
export declare type RadiationDoseRate = typeof RadiationDoseRate;
export declare const ElectronMobility: Measure<Pick<{
    length: 0;
    mass: -1;
    time: 2;
    current: 1;
}, "mass" | "time" | "current">>;
export declare type ElectronMobility = typeof ElectronMobility;
export declare const AngularMomentum: Measure<Pick<{
    length: 2;
    mass: 1;
    time: -1;
}, "length" | "mass" | "time">>;
export declare type AngularMomentum = typeof AngularMomentum;
export declare const SpecificAngularMomentum: Measure<Pick<{
    length: 2;
    mass: 0;
    time: -1;
}, "length" | "time">>;
export declare type SpecificAngularMomentum = typeof SpecificAngularMomentum;
export declare const Luminance: Measure<Pick<{
    length: -2;
    intensity: 1;
}, "length" | "intensity">>;
export declare type Luminance = typeof Luminance;
export declare const LuminousFlux: Measure<Pick<{
    intensity: 1;
    solidAngle: 1;
}, "intensity" | "solidAngle">>;
export declare type LuminousFlux = typeof LuminousFlux;
export declare const Illuminance: Measure<Pick<{
    length: -2;
    intensity: 1;
    solidAngle: 1;
}, "length" | "intensity" | "solidAngle">>;
export declare type Illuminance = typeof Illuminance;
export declare const LuminousEnergy: Measure<Pick<{
    time: 1;
    intensity: 1;
    solidAngle: 1;
}, "time" | "intensity" | "solidAngle">>;
export declare type LuminousEnergy = typeof LuminousEnergy;
export declare const LuminousExposure: Measure<Pick<{
    length: -2;
    time: 1;
    intensity: 1;
    solidAngle: 1;
}, "length" | "time" | "intensity" | "solidAngle">>;
export declare type LuminousExposure = typeof LuminousExposure;
export declare const LuminousEfficiency: Measure<Pick<{
    length: -2;
    mass: -1;
    time: 3;
    intensity: 1;
    solidAngle: 1;
}, "length" | "mass" | "time" | "intensity" | "solidAngle">>;
export declare type LuminousEfficiency = typeof LuminousEfficiency;
export declare const RadiantIntensity: Measure<Pick<{
    length: 2;
    mass: 1;
    time: -3;
    solidAngle: -1;
}, "length" | "mass" | "time" | "solidAngle">>;
export declare type RadiantIntensity = typeof RadiantIntensity;
export declare const SpectralIntensity: Measure<Pick<{
    length: 1;
    mass: 1;
    time: -3;
    solidAngle: -1;
}, "length" | "mass" | "time" | "solidAngle">>;
export declare type SpectralIntensity = typeof SpectralIntensity;
export declare const Radiance: Measure<Pick<{
    length: 0;
    mass: 1;
    time: -3;
    solidAngle: -1;
}, "mass" | "time" | "solidAngle">>;
export declare type Radiance = typeof Radiance;
export declare const SpectralRadiance: Measure<Pick<{
    length: -1;
    mass: 1;
    time: -3;
    solidAngle: -1;
}, "length" | "mass" | "time" | "solidAngle">>;
export declare type SpectralRadiance = typeof SpectralRadiance;
export declare const AngularVelocity: Measure<Pick<{
    time: -1;
    planeAngle: 1;
}, "time" | "planeAngle">>;
export declare type AngularVelocity = typeof AngularVelocity;
export declare const AngularAcceleration: Measure<Pick<{
    time: -2;
    planeAngle: 1;
}, "time" | "planeAngle">>;
export declare type AngularAcceleration = typeof AngularAcceleration;
